@@ -38,14 +38,7 @@
 
 #include <signal.h> //For SIGTERM
 
-#include <kauth_version.h>
-#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
 #include <KAuth/Action>
-#else
-#include <KAuth>
-#include <KAuthAction>
-#include <KAuthActionReply>
-#endif
 #include <KDialogJobUiDelegate>
 #include <KGlobalAccel>
 #include <KIO/ApplicationLauncherJob>
@@ -772,7 +765,7 @@ void KSysGuardProcessList::showColumnContextMenu(const QPoint &point)
     if (d->mUi->treeView->header()->sectionsHidden()) {
         for (int i = 0; i < num_headings; ++i) {
             if (d->mUi->treeView->header()->isSectionHidden(i)) {
-#ifndef HAVE_XRES
+#if !HAVE_XRES
                 if (i == ProcessModel::HeadingXMemory)
                     continue;
 #endif
@@ -1176,7 +1169,7 @@ bool KSysGuardProcessList::reniceProcesses(const QList<long long> &pids, int nic
         updateList();
         return true;
     } else if (result == KSysGuard::ProcessController::Result::Error) {
-        KMessageBox::sorry(this,
+        KMessageBox::error(this,
                            i18n("You do not have the permission to renice the process and there "
                                 "was a problem trying to run as root."));
     }
@@ -1203,7 +1196,7 @@ void KSysGuardProcessList::reniceSelectedProcesses()
         QStringList selectedAsStrings;
 
         if (processes.isEmpty()) {
-            KMessageBox::sorry(this, i18n("You must select a process first."));
+            KMessageBox::error(this, i18n("You must select a process first."));
             return;
         }
 
@@ -1327,7 +1320,7 @@ bool KSysGuardProcessList::changeIoScheduler(const QList<long long> &pids, KSysG
         updateList();
         return true;
     } else if (result == KSysGuard::ProcessController::Result::Error) {
-        KMessageBox::sorry(this,
+        KMessageBox::error(this,
                            i18n("You do not have the permission to change the I/O priority of the process and there "
                                 "was a problem trying to run as root."));
     }
@@ -1343,7 +1336,7 @@ bool KSysGuardProcessList::changeCpuScheduler(const QList<long long> &pids, KSys
         updateList();
         return true;
     } else if (result == KSysGuard::ProcessController::Result::Error) {
-        KMessageBox::sorry(this,
+        KMessageBox::error(this,
                            i18n("You do not have the permission to change the CPU Scheduler for the process and there "
                                 "was a problem trying to run as root."));
     }
@@ -1358,7 +1351,7 @@ bool KSysGuardProcessList::killProcesses(const QList<long long> &pids, int sig)
         updateList();
         return true;
     } else if (result == KSysGuard::ProcessController::Result::Error) {
-        KMessageBox::sorry(this,
+        KMessageBox::error(this,
                            i18n("You do not have the permission to kill the process and there "
                                 "was a problem trying to run as root."));
     }
@@ -1387,7 +1380,7 @@ void KSysGuardProcessList::sendSignalToSelectedProcesses(int sig, bool confirm)
 
     if (selectedPids.isEmpty()) {
         if (confirm)
-            KMessageBox::sorry(this, i18n("You must select a process first."));
+            KMessageBox::error(this, i18n("You must select a process first."));
         return;
     } else if (confirm && (sig == SIGTERM || sig == SIGKILL)) {
         int count = selectedAsStrings.count();
